from django.contrib.admin.views.main import ChangeList

from .settings import get_settings


class TranslationChangeList(ChangeList):
    def __init__(self, *args, **kwargs):
        super(TranslationChangeList, self).__init__(*args, **kwargs)

        if self.result_list:
            self.prep_hints()

    def prep_hints(self):
        from .models import TranslationEntry

        entry_ids = [str(entry.id) for entry in self.result_list]
        hint_language_forced_locale_path = get_settings('TRANSLATIONS_HINT_LANGUAGE_FORCED_RELATIVE_LOCALE_PATH')
        if not hint_language_forced_locale_path:
            hint_language_forced_locale_path = 'te1.locale_path'
        else:
            hint_language_forced_locale_path = "'%s'" % hint_language_forced_locale_path

        hint_sql_template = "SELECT te2.* FROM %s AS te1 INNER JOIN %s AS te2 ON (te1.original = te2.original AND te1.domain = te2.domain AND te2.locale_path = %s) WHERE te2.is_published = TRUE AND te1.id IN (%s) AND te2.language = '%s'"
        hint_sql = hint_sql_template % (TranslationEntry._meta.db_table, TranslationEntry._meta.db_table, hint_language_forced_locale_path, ",".join(entry_ids), get_settings('TRANSLATIONS_HINT_LANGUAGE'))
        hint_qs = TranslationEntry.objects.raw(hint_sql)
        hint_dict = dict([(hint.original, hint.translation) for hint in hint_qs])

        for result in self.result_list:
            result._hint = hint_dict.get(result.original, "")




import os

from django.db.models import Q

from .settings import get_settings


def get_relative_locale_path(pofile):
    "Returns relative path of locale dir to project root dir ['/foo/bar', '/foo/bar/locale'] => 'locale'"
    locale_dir = os.path.dirname(os.path.dirname(os.path.dirname(pofile)))
    rel_path = os.path.relpath(locale_dir, get_settings('TRANSLATIONS_BASE_DIR'))
    return rel_path


def get_locale_parent_dirname(pofile):
    "Returns name of locale's dir parent ['/foo/bar', '/foo/bar/locale'] => 'bar'"
    locale_dir = os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(pofile))))
    dirname = os.path.relpath(locale_dir, os.path.join(locale_dir, ".."))
    return dirname


def get_dirname_from_lang(lang):
    "Converts lang in format en-gb to format en_GB"
    dirname = lang
    if len(lang) > 2:
        dirname = lang[:2] + "_" + lang[3:].upper()
    return dirname


def get_lang_from_dirname(dirname):
    "Converts lang in format en_GB to format en-gb"
    lang = dirname
    if len(dirname) > 2:
        lang = dirname[:2] + "-" + lang[3:].lower()
    return lang


def filter_queryset(qs):
    qs = qs.filter(is_published=True)
    if get_settings('TRANSLATIONS_QUERYSET_FORCE_FILTERS'):
        filter_ = get_settings('TRANSLATIONS_QUERYSET_FORCE_FILTERS')[0]
        q = Q(original__contains=filter_)
        for filter_ in get_settings('TRANSLATIONS_QUERYSET_FORCE_FILTERS')[1:]:
            q = q | Q(original__contains=filter_)
        qs = qs.filter(q)
    return qs




def add_styles(widget, styles):
    """ Helper function - adds CSS styles to widget

    """
    attrs = widget.attrs or {}
    if 'style' in attrs:
        attrs['style'] = '%s %s' % (attrs['style'], styles)
    else:
        attrs['style'] = styles
    widget.attrs = attrs


# -*- coding: utf-8 -*-

import codecs
import os
import polib

from datetime import datetime

from django import VERSION
from django.conf import settings

from glob import glob

from .choices import TRANSLATIONS_MODE_PROMISCUOUS
from .models import TranslationEntry, TranslationBackup
from .utils import get_relative_locale_path, get_locale_parent_dirname, get_dirname_from_lang, get_lang_from_dirname
from .settings import get_settings


class Manager(object):

    def __init__(self, *args, **kwargs):
        super(Manager, self).__init__(*args, **kwargs)

        self.tors = {}

    def store_to_db(self, pofile, locale, store_translations=False):
        language = get_lang_from_dirname(locale)
        domain = os.path.splitext(os.path.basename(pofile))[0]
        messages = polib.pofile(pofile)
        translations = TranslationEntry.objects.filter(language=language)

        tdict = {}
        for t in translations:
            if t.original not in tdict:
                tdict.update({t.original: {}})
            tdict[t.original][t.language] = t.translation

        for m in messages:
            occs = []
            for occ in m.occurrences:
                path = ":".join(occ)
                occs.append(path)

            if store_translations:
                translation = m.msgstr
            else:
                translation = ""

            locale_path = get_relative_locale_path(pofile)
            t, created = TranslationEntry.objects.get_or_create(
                original=m.msgid,
                language=language,
                locale_path=locale_path,
                domain=domain,
                defaults={
                    "occurrences": "\n".join(occs),
                    "translation": translation,
                    "locale_parent_dir": get_locale_parent_dirname(pofile),
                    "is_published": True,
                }
            )

            if not locale_path in self.tors:
                self.tors[locale_path] = []
            self.tors[locale_path].append(t.original)

    ############################################################################

    def backup_po_to_db(self):
        """ Backup Po file to db model """


        for lang, lang_name in settings.LANGUAGES:
            for path in settings.LOCALE_PATHS:
                po_pattern = os.path.join(path, get_dirname_from_lang(lang), "LC_MESSAGES", "*.po")
                for pofile in glob(po_pattern):
                    if settings.DEBUG:
                        print ("Backuping", pofile)

                    domain = os.path.splitext(os.path.basename(pofile))[0]
                    with codecs.open(pofile, 'r', 'utf-8') as pofile_opened:
                        content = pofile_opened.read()
                        backup = TranslationBackup(
                            language=lang,
                            locale_path=get_relative_locale_path(pofile),
                            domain=domain,
                            locale_parent_dir=get_locale_parent_dirname(pofile),
                            content=content,
                        )
                        backup.save()

                    if get_settings('TRANSLATIONS_CLEAN_PO_AFTER_BACKUP'):
                        with open(pofile, 'w') as pofile_opened:
                            pofile_opened.write('')


    ############################################################################


    def update_po_from_db(self, lang):

        translations = TranslationEntry.objects.filter(
            language=lang,
            is_published=True
        ).exclude(
            translation=""
        ).order_by("original")

        locale_params = TranslationEntry.objects.filter(is_published=True).order_by('locale_path', 'domain')

        forced_locale_paths = get_settings('TRANSLATIONS_UPDATE_FORCED_LOCALE_PATHS')
        if forced_locale_paths:
            translations = translations.filter(locale_path__in=forced_locale_paths)
            locale_params = locale_params.filter(locale_path__in=forced_locale_paths)

        locale_params = locale_params.values_list('locale_path', 'domain')
        locale_params = list(set(locale_params))

        for locale_path, domain in locale_params:
            pofile_path = os.path.join(get_settings('TRANSLATIONS_BASE_DIR'), locale_path, get_dirname_from_lang(lang), 'LC_MESSAGES', "%s.po" % domain)
            mofile_path = os.path.join(get_settings('TRANSLATIONS_BASE_DIR'), locale_path, get_dirname_from_lang(lang), 'LC_MESSAGES', "%s.mo" % domain)

            if not os.path.exists(pofile_path):
                if settings.DEBUG:
                    print ("Po file '%s' does't exists, it will be created" % pofile_path)

            now = datetime.now()
            pofile = polib.POFile()
            pofile.metadata = {
                'Project-Id-Version': '0.1',
                'Report-Msgid-Bugs-To': '%s' % settings.DEFAULT_FROM_EMAIL,
                'POT-Creation-Date': now.strftime("%Y-%m-%d %H:%M:%S"),
                'PO-Revision-Date': now.strftime("%Y-%m-%d %H:%M:%S"),
                'Last-Translator': 'Server <%s>' % settings.SERVER_EMAIL,
                'Language-Team': 'English <%s>' % settings.DEFAULT_FROM_EMAIL,
                'MIME-Version': '1.0',
                'Content-Type': 'text/plain; charset=utf-8',
                'Content-Transfer-Encoding': '8bit',
            }

            for translation in translations.filter(locale_path=locale_path, domain=domain):
                entry = polib.POEntry(
                    msgid=translation.original,
                    msgstr=translation.translation,
                    occurrences=[occ.split(":") for occ in translation.occurrences.split()]
                )
                pofile.append(entry)

            pofile.save(pofile_path)
            pofile.save_as_mofile(mofile_path)

    ############################################################################

    def postprocess(self):
        TranslationEntry.objects.all().update(is_published=False)
        for locale_path, tors in self.tors.items():
            tors = list(set(tors))
            TranslationEntry.objects.filter(locale_path=locale_path).filter(original__in=tors).update(is_published=True)

        if get_settings('TRANSLATIONS_MODE')== TRANSLATIONS_MODE_PROMISCUOUS:
            published = TranslationEntry.objects.filter(is_published=True).order_by("original", 'language', 'locale_path')
            for trans in published:
                if VERSION[:2] in [(1,2), (1,3)]:
                    locale_paths = [os.path.relpath(path, get_settings('TRANSLATIONS_BASE_DIR')) for path in settings.LOCALE_PATHS]
                else:
                    locale_paths = self.tors.keys()
                for locale_path in locale_paths:
                    t, created = TranslationEntry.objects.get_or_create(
                        original=trans.original,
                        language= trans.language,
                        locale_path=locale_path,
                        defaults={
                            "occurrences": trans.occurrences,
                            "translation": trans.translation,
                            "locale_parent_dir": get_locale_parent_dirname(os.path.join(
                                get_settings('TRANSLATIONS_BASE_DIR'),
                                locale_path,
                                get_dirname_from_lang(trans.language),
                                'LC_MESSAGES',
                                "django.po"
                            )),
                            "is_published": True,
                        }
                    )
            TranslationEntry.objects.filter(original__in=published.values_list('original', flat=True)).update(is_published=True)

    ############################################################################

    def load_data_from_po(self):
        import os

        for lang, lang_name in settings.LANGUAGES:
            for path in settings.LOCALE_PATHS:
                locale = get_dirname_from_lang(lang)
                po_pattern = os.path.join(path, locale, "LC_MESSAGES", "*.po")
                for pofile in glob(po_pattern):
                    if settings.DEBUG:
                        print ("processing pofile", pofile)
                    self.store_to_db(pofile=pofile, locale=locale, store_translations=True)

        self.postprocess()



from django.conf import settings
from . import defaults


def get_settings(setting):
    """
    Looks for settings in django settings or in translation_manager.defaults
    """
    return getattr(settings, setting, getattr(defaults, setting))




import polib
import os

from django.db import models
from django.template.defaultfilters import capfirst as cf
from django.utils.translation import ugettext_lazy as _

from .settings import get_settings


class TranslationEntry(models.Model):
    created = models.DateTimeField(auto_now_add=True, verbose_name=_(u"admin-translation_entry-created-label"))
    changed = models.DateTimeField(auto_now=True, verbose_name=_(u"admin-translation_entry-changed-label"))
    language = models.CharField(db_index=True, max_length=5, verbose_name=_(u"admin-translation_entry-language-label"))
    original = models.TextField(verbose_name=_(u"admin-translation_entry-original-label"))
    translation = models.TextField(blank=True, verbose_name=_(u"admin-translation_entry-translation-label"))
    occurrences = models.TextField(blank=True, verbose_name=_(u"admin-translation_entry-occurrences-label"))
    is_published = models.BooleanField(default=True, editable=False, verbose_name=_(u"admin-translation_entry-is_published-label"))
    locale_path = models.CharField(db_index=True, max_length=256, verbose_name=_(u"admin-translation_entry-locale_path-label"))
    locale_parent_dir = models.CharField(db_index=True, max_length=256, verbose_name=_(u"admin-translation_entry-locale_parent_dir-label"))
    domain = models.CharField(db_index=True, max_length=256, verbose_name=_(u"admin-translation_entry-domain-label"))

    class Meta:
        verbose_name = cf(_(u"admin-translation_entry-singular"))
        verbose_name_plural = cf(_(u"admin-translation_entry-plural"))
        ordering = ('original',)
        permissions = (
            ('load', _('admin-translation_entry-load-from-po')),
        )

    def __unicode__(self):
        return "(%s:%s:%s:%s)" % (self.pk, self.original[:64], self.language, self.locale_path)

    def __str__(self):
        return "(%s:%s:%s:%s)" % (self.pk, self.original[:64], self.language, self.locale_path)

    def get_hint(self):
        self.hint = ""

        if not self.hint:
            if hasattr(self, '_hint'):
                self.hint = self._hint
            else:
                try:
                    self.hint = self._meta.model.objects.get(domain=self.domain, locale_path=self.locale_path, original=self.original, language=get_settings('TRANSLATIONS_HINT_LANGUAGE')).translation
                except self._meta.model.DoesNotExist:
                    pass

        return self.hint
    get_hint.short_description = cf(_("admin-translation_entry-hint-label"))


class TranslationBackup(models.Model):
    created = models.DateTimeField(auto_now_add=True, verbose_name=_(u"admin-translation_backup-created-label"))
    changed = models.DateTimeField(auto_now=True, verbose_name=_(u"admin-translation_backup-changed-label"))
    language = models.CharField(db_index=True, max_length=5, verbose_name=_(u"admin-translation_backup-language-label"))
    locale_path = models.CharField(db_index=True, max_length=256, verbose_name=_(u"admin-translation_backup-locale_path-label"))
    locale_parent_dir = models.CharField(db_index=True, max_length=256, verbose_name=_(u"admin-translation_backup-locale_parent_dir-label"))
    domain = models.CharField(db_index=True, max_length=256, verbose_name=_(u"admin-translation_backup-domain-label"))

    content = models.TextField(verbose_name=_(u"admin-translation_backup-content"))

    class Meta:
        verbose_name = cf(_(u"admin-translation_backup-singular"))
        verbose_name_plural = cf(_(u"admin-translation_backup-plural"))
        ordering = ('-created',)

    def restore(self):
        po_filename = os.path.join(get_settings('TRANSLATIONS_BASE_DIR'), self.locale_path, self.language, 'LC_MESSAGES',
                                   self.domain + '.mo')

        mo_filename = os.path.join(get_settings('TRANSLATIONS_BASE_DIR'), self.locale_path, self.language, 'LC_MESSAGES',
                                   self.domain + '.mo')

        with open(po_filename, 'w') as output:
            output.write(self.content.encode('utf-8'))

        po = polib.pofile(po_filename)
        po.save_as_mofile(mo_filename)

    def __unicode__(self):
        return "(%s:%s:%s)" % (self.pk, self.language, self.locale_path)

    def __str__(self):
        return "(%s:%s:%s)" % (self.pk, self.language, self.locale_path)



from django import VERSION
from django.contrib import admin
from django.utils.text import capfirst as cf
from django.utils.translation import ugettext as _

from . import choices
from .settings import get_settings

if (VERSION[0] == 1 and VERSION[1] >= 4) or VERSION[0] > 1:
    class TranslationStateFilter(admin.SimpleListFilter):
        title = _('admin-translation_manager-translation_state_filter-title')
        parameter_name = 'state'

        def lookups(self, request, model_admin):
            return (
                (choices.TRANSLATIONS_TRANSLATED, _('admin-translation_manager-translation_state_filter-translated')),
                (choices.TRANSLATIONS_UNTRANSLATED, _('admin-translation_manager-translation_state_filter-untranslated')),
            )

        def queryset(self, request, queryset):
            all_count = queryset.count()
            translated_count = queryset.exclude(translation='').count()
            untranslated_count = all_count - translated_count

            translated_title = u'{translated_label} ({translated_count} / {all_count})'.format(
                translated_label=self.lookup_choices[0][1],
                translated_count=translated_count,
                all_count=all_count,
            )

            untranslated_title = u'{translated_label} ({untranslated_count} / {all_count})'.format(
                translated_label=self.lookup_choices[1][1],
                untranslated_count=untranslated_count,
                all_count=all_count,
            )

            self.lookup_choices = [
                (choices.TRANSLATIONS_TRANSLATED, cf(translated_title)),
                (choices.TRANSLATIONS_UNTRANSLATED, cf(untranslated_title)),
            ]

            if self.value() == choices.TRANSLATIONS_TRANSLATED:
                return queryset.exclude(translation="")
            if self.value() == choices.TRANSLATIONS_UNTRANSLATED:
                return queryset.filter(translation="")

    class CustomFilter(admin.SimpleListFilter):
        title = _('admin-translation_manager-translation_custom_filter-title')
        parameter_name = 'custom_filter'

        def __init__(self, *args, **kwargs):
            self.title = cf(_(get_settings('TRANSLATIONS_CUSTOM_FILTERS')[0][1]))
            super(CustomFilter, self).__init__(*args, **kwargs)

        def lookups(self, request, model_admin):
            return [(i, cf(_(label))) for i, (group_filter, label) in enumerate(get_settings('TRANSLATIONS_CUSTOM_FILTERS'))]

        def queryset(self, request, queryset):
            active_filter = self.value()
            if not active_filter:
                return queryset
            else:
                filter_value, label = get_settings('TRANSLATIONS_CUSTOM_FILTERS')[int(active_filter)]
                return queryset.filter(original__regex=filter_value)



from functools import update_wrapper

from django import VERSION
from django.contrib import admin
from django.core.management import call_command
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect
from django.utils.translation import ugettext_lazy as _
from django.conf import settings

from .manager import Manager
from .models import TranslationEntry, TranslationBackup
from .signals import post_save
from .widgets import add_styles
from .utils import filter_queryset
from .settings import get_settings


filter_excluded_fields = lambda fields: [field for field in fields if field not in get_settings('TRANSLATIONS_ADMIN_EXCLUDE_FIELDS')]


class TranslationEntryAdmin(admin.ModelAdmin):
    actions_on_bottom = True
    save_on_top = True

    default_fields = ['original', 'language', 'get_hint', 'translation', 'occurrences', 'locale_parent_dir', 'domain']

    list_fields = filter_excluded_fields(get_settings('TRANSLATIONS_ADMIN_FIELDS'))
    if not list_fields:
        list_fields = filter_excluded_fields(default_fields)

    fields = default_fields
    list_display = list_fields
    list_editable = ('translation',)
    ordering = ('original', 'language')
    readonly_fields = list(default_fields)
    readonly_fields.remove('original')
    search_fields = filter_excluded_fields(['original', 'translation', 'occurrences'])
    list_per_page = 100

    if (VERSION[0] == 1 and VERSION[1] >= 4) or VERSION[0] > 1:
        from .filters import TranslationStateFilter, CustomFilter
        list_filter = ['language', 'locale_parent_dir', 'domain', TranslationStateFilter]
        if get_settings('TRANSLATIONS_CUSTOM_FILTERS'):
            list_filter.append(CustomFilter)
    else:
        list_filter = ('language', 'locale_parent_dir', 'domain')

    if (VERSION[0] == 1 and VERSION[1] >= 7) or VERSION[0] > 1:
        change_list_template = "admin/translation_manager/change_list.7.html"
    else:
        change_list_template = "admin/translation_manager/change_list.2.html"

    list_filter = filter_excluded_fields(list_filter)

    def formfield_for_dbfield(self, db_field, **kwargs):
        formfield = super(TranslationEntryAdmin, self).formfield_for_dbfield(db_field, **kwargs)
        if db_field.name == 'translation':
            add_styles(formfield.widget, u'height: 26px;')
        return formfield

    def get_urls(self):
        try:
            from django.conf.urls import patterns, url
        except ImportError:
            # Old django fix
            from django.conf.urls.defaults import patterns, url
 
        def wrap(view):
            def wrapper(*args, **kwargs):
                return self.admin_site.admin_view(view)(*args, **kwargs)
            return update_wrapper(wrapper, view)
 
        try:
            info = self.model._meta.app_label, self.model._meta.model_name
        except AttributeError:
            # Old django fix
            info = self.model._meta.app_label, self.model._meta.module_name
 
        urls = patterns('',
            url(r'^make/$', wrap(self.make_translations_view), name='%s_%s_make' % info),
            url(r'^compile/$', wrap(self.compile_translations_view), name='%s_%s_compile' % info),
            url(r'^load_from_po/$', wrap(self.load_from_po_view), name='%s_%s_load' % info),
        )
 
        super_urls = super(TranslationEntryAdmin, self).get_urls()
 
        return urls + super_urls

    def get_queryset(self, request):
        qs = super(TranslationEntryAdmin, self).get_queryset(request=request)
        return filter_queryset(qs)

    # older django
    def queryset(self, request):
        qs = super(TranslationEntryAdmin, self).queryset(request=request)
        return filter_queryset(qs)


    def load_from_po_view(self, request):
        if request.user.has_perm('translation_manager.load'):
            manager = Manager()
            manager.load_data_from_po()

            self.message_user(request, _("admin-translation_manager-data-loaded_from_po"))
        return HttpResponseRedirect(reverse("admin:translation_manager_translationentry_changelist"))

    def make_translations_view(self, request):
        call_command('makemessages')

        self.message_user(request, _("admin-translation_manager-translations_made"))
        return HttpResponseRedirect(reverse("admin:translation_manager_translationentry_changelist"))

    def compile_translations_view(self, request):
        manager = Manager()
        for language, language_name in settings.LANGUAGES:
            manager.update_po_from_db(lang=language)
        post_save.send(sender=None, request=request)

        self.message_user(request, _("admin-translation_manager-translations_compiled"))
        return HttpResponseRedirect(reverse("admin:translation_manager_translationentry_changelist"))

    def get_changelist(self, request, **kwargs):

        from .views import TranslationChangeList
        return TranslationChangeList


def restore(modeladmin, request, queryset):
    for backup in queryset:
        backup.restore()
restore.short_description = _("admin-translation_manager-backups_restore_option")


class TranslationBackupAdmin(admin.ModelAdmin):
    actions_on_bottom = True
    actions = [restore]
    save_on_top = True
    fields = ('created', 'language', 'locale_parent_dir', 'domain', 'content')
    list_display = ('created', 'language', 'locale_parent_dir', 'domain')
    list_filter = ('created', 'language', 'locale_parent_dir', 'domain')
    readonly_fields = ('created', 'language', 'locale_parent_dir', 'domain')


admin.site.register(TranslationEntry, TranslationEntryAdmin)
admin.site.register(TranslationBackup, TranslationBackupAdmin)



"""
Settings required in you project settings.
Please modify according to your requirements.
Usage can be found in example project.
"""

# Required paths to all locale dirs
# LOCALE_PATHS = [
#     '/foo/bar/locale',
#     '/foo/foo/bar/locale',
# ]
LOCALE_PATHS = []

# Path to project basedir / workdir - root folder of project
# TRANSLATIONS_BASE_DIR = '/foo/bar'
TRANSLATIONS_BASE_DIR = ''

# Mode the translation manager behaves when creating
# translations mainly from multiple locale files
# Default value is N, where translation in DB are 
# only once for specific locale file.
# Another option is P, where is translation manager
# promiscuous and creates for every translation it's
# instance for every locale file. It's useful, i.e.
# if you want has original system trasnlations and
# also client's custom translations

TRANSLATIONS_MODE = "N"

# For storing all translations to db regardless they have
# any occurrencies or not set True, otherwise set False.
# If False only translations having occurrencies in your
# application will be stored.
TRANSLATIONS_ALLOW_NO_OCCURRENCES = False

# Dirs and files ignored for makemessages.
# TRANSLATIONS_IGNORED_PATHS = ['env', 'foo', 'bar']
TRANSLATIONS_IGNORED_PATHS = ['env']

# Backup on makemessages:
TRANSLATIONS_MAKE_BACKUPS = True

# Clean .po files (delete content) after backup (this prevents duplicities)
TRANSLATIONS_CLEAN_PO_AFTER_BACKUP = True

# Forced filters on changelist queryset.
# Uses ORed original__contains Django ORM filter.
# TRANSLATIONS_QUERYSET_FORCE_FILTERS = ['foo', 'bar']
TRANSLATIONS_QUERYSET_FORCE_FILTERS = []

# Language to display in hint column to help translators
# see translation of string in another language
# TRANSLATIONS_HINT_LANGUAGE = 'foo'
TRANSLATIONS_HINT_LANGUAGE = ''

# Relative path to locale dir with hint languages
# Current locale path of translated string used by default
TRANSLATIONS_HINT_LANGUAGE_FORCED_RELATIVE_LOCALE_PATH = ''

# exclude fields from administration:
TRANSLATIONS_ADMIN_EXCLUDE_FIELDS = []

# Define admin fields manually: for all fields look to admin.py:default_fields
TRANSLATIONS_ADMIN_FIELDS = []

# Tuple of title and list of regex expression used for filtering in administration.
# Each object should be a tuple of (regex_filter, label)
TRANSLATIONS_CUSTOM_FILTERS = []

# Limits locale paths of published translations when updating POs from DB.
TRANSLATIONS_UPDATE_FORCED_LOCALE_PATHS = []



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

PACKAGE = "translation_manager"
NAME = "django-translation-manager"
DESCRIPTION = "Django app for managing translations from admin"
AUTHOR = "Pavel Císař, Martin Kubát, Mikuláš Mrva, COEX CZ s.r.o (http://www.coex.cz)"
AUTHOR_EMAIL = "cisarpavel@gmail.com"
URL = "https://github.com/COEXCZ/django-translation-manager"
VERSION = '0.2.2'
LICENSE = "CC BY-NC 3.0"

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    license=LICENSE,
    url=URL,
    packages=["translation_manager"],
    include_package_data=True,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: Free for non-commercial use",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Internationalization"
    ],
    install_requires=[
        "polib",
        "django>=1.2"
    ],
)